from distutils.core import setup

setup(
    name = 'one-piece',
    py_modules = ['onepiece'],
    version = '0.1',
    description = 'onepiece',
    author = 'kuga',
    author_email = 'kugacola@gmail.com',
    url = 'http://kuga.me',
    keywords = ['onepiece'],
)
